pub struct ConnectionHandle { /* private fields */ }Expand description
A handle to a backend. Communicates to a ConnectionInterface on the
backend.
The backend SHOULD shut down when the handle is dropped (as indicated by the shutdown channel).
Implementations
Sourceimpl ConnectionHandle
impl ConnectionHandle
Sourcepub fn new() -> (Self, ConnectionInterface)
pub fn new() -> (Self, ConnectionInterface)
Create a new connection handle.
Sourcepub const fn with_max_retries(self, max_retries: u32) -> Self
pub const fn with_max_retries(self, max_retries: u32) -> Self
Set the max number of retries before failing and exiting the connection. Default is 10.
Sourcepub const fn with_retry_interval(self, retry_interval: Duration) -> Self
pub const fn with_retry_interval(self, retry_interval: Duration) -> Self
Set the base interval between retries.
Reconnect retries use capped exponential backoff from this base interval.