ConnectionInterface

Struct ConnectionInterface 

pub struct ConnectionInterface { /* private fields */ }
The reciprocal of ConnectionHandle.

Implementations

Source

impl ConnectionInterface

pub fn send_to_frontend( &self, item: PubSubItem, ) -> Result<(), SendError<PubSubItem>>

Send a pubsub item to the frontend.

pub async fn recv_from_frontend(&mut self) -> Option<Box<RawValue>>

Receive a request from the frontend. Ensures that if the frontend has dropped or issued a shutdown instruction, the backend sees no more requests.

pub fn close_with_error(self)

Close the interface, signaling a generic backend-gone error to the frontend.

The pubsub service will attempt to reconnect using the configured retry policy. Use Self::close_with_transport_error to opt out of the reconnect loop on deterministic, non-retryable failures.

pub fn close_with_transport_error(self, err: TransportError)

Close the interface, signaling a specific transport error to the frontend.

Use TransportErrorKind::non_retryable_str / TransportErrorKind::non_retryable to construct an error that short-circuits the pubsub service’s reconnect loop. Any other error kind triggers the normal reconnect-with-retries path.