pub struct InFlight {
pub request: SerializedRequest,
pub channel_size: usize,
pub tx: Sender<TransportResult<Response>>,
}Expand description
An in-flight JSON-RPC request.
This struct contains the request that was sent, as well as a channel to receive the response on.
Fields
request: SerializedRequestThe request
channel_size: usizeThe number of items to buffer in the subscription channel.
tx: Sender<TransportResult<Response>>The channel to send the response on.
Implementations
Sourceimpl InFlight
impl InFlight
Sourcepub fn new(
request: SerializedRequest,
channel_size: usize,
) -> (Self, Receiver<TransportResult<Response>>)
pub fn new( request: SerializedRequest, channel_size: usize, ) -> (Self, Receiver<TransportResult<Response>>)
Create a new in-flight request.
Sourcepub fn is_subscription(&self) -> bool
pub fn is_subscription(&self) -> bool
Check if the request is a subscription.
Sourcepub const fn request(&self) -> &SerializedRequest
pub const fn request(&self) -> &SerializedRequest
Get a reference to the serialized request.
This is used to (re-)send the request over the transport.