pub struct PubSubFrontend { /* private fields */ }Expand description
A PubSubFrontend is Transport composed of a channel to a running
PubSub service.
Implementations
Sourceimpl PubSubFrontend
impl PubSubFrontend
Sourcepub fn new(tx: UnboundedSender<PubSubInstruction>) -> Self
pub fn new(tx: UnboundedSender<PubSubInstruction>) -> Self
Create a new frontend.
Sourcepub fn get_subscription(
&self,
id: B256,
) -> impl Future<Output = TransportResult<RawSubscription>> + Send + 'static
pub fn get_subscription( &self, id: B256, ) -> impl Future<Output = TransportResult<RawSubscription>> + Send + 'static
Get the subscription ID for a local ID.
Sourcepub fn unsubscribe(&self, id: B256) -> TransportResult<()>
pub fn unsubscribe(&self, id: B256) -> TransportResult<()>
Unsubscribe from a subscription.
Sourcepub fn send(
&self,
req: SerializedRequest,
) -> impl Future<Output = TransportResult<Response>> + Send + 'static
pub fn send( &self, req: SerializedRequest, ) -> impl Future<Output = TransportResult<Response>> + Send + 'static
Send a request.
Sourcepub fn send_packet(&self, req: RequestPacket) -> TransportFut<'static>
pub fn send_packet(&self, req: RequestPacket) -> TransportFut<'static>
Send a packet of requests, by breaking it up into individual requests.
Once all responses are received, we return a single response packet.
Sourcepub fn channel_size(&self) -> usize
pub fn channel_size(&self) -> usize
Get the currently configured channel size. This is the number of items
to buffer in new subscription channels. Defaults to 16. See
tokio::sync::broadcast for a description of relevant
behavior.
Sourcepub fn set_channel_size(&self, channel_size: usize)
pub fn set_channel_size(&self, channel_size: usize)
Set the channel size. This is the number of items to buffer in new
subscription channels. Defaults to 16. See
tokio::sync::broadcast for a description of relevant
behavior.