RawSubscription

Struct RawSubscription 

pub struct RawSubscription {
    pub rx: Receiver<Box<RawValue>>,
    pub local_id: B256,
}
A Subscription is a feed of notifications from the server, identified by a local ID.

This type is mostly a wrapper around broadcast::Receiver, and exposes the same methods.

Fields

rx: Receiver<Box<RawValue>>

The channel via which notifications are received.

local_id: B256

The local ID of the subscription.

Implementations

Source

impl RawSubscription

pub const fn local_id(&self) -> &B256

Get the local ID of the subscription.

pub fn blocking_recv(&mut self) -> Result<Box<RawValue>, RecvError>

Wrapper for blocking_recv. Block the current thread until a message is available.

pub fn is_empty(&self) -> bool

Returns true if the broadcast channel is empty (i.e. there are currently no notifications to receive).

pub fn len(&self) -> usize

Returns the number of messages in the broadcast channel that this receiver has yet to receive.

pub async fn recv(&mut self) -> Result<Box<RawValue>, RecvError>

Wrapper for recv. Await an item from the channel.

pub fn resubscribe(&self) -> Self

Wrapper for resubscribe. Create a new Subscription, starting from the current tail element.

pub fn same_channel(&self, other: &Self) -> bool

Wrapper for same_channel. Returns true if the two subscriptions share the same broadcast channel.

pub fn try_recv(&mut self) -> Result<Box<RawValue>, TryRecvError>

Wrapper for try_recv. Attempt to receive a message from the channel without awaiting.

pub fn into_stream(self) -> BroadcastStream<Box<RawValue>>

Convert the subscription into a stream.

pub fn into_typed<T>(self) -> Subscription<T>

Convert into a typed subscription.