Struct InFlight

pub struct InFlight {
    pub request: SerializedRequest,
    pub channel_size: usize,
    pub tx: Sender<TransportResult<Response>>,
}
An in-flight JSON-RPC request.

This struct contains the request that was sent, as well as a channel to receive the response on.

Fields

request: SerializedRequest

The request

channel_size: usize

The number of items to buffer in the subscription channel.

tx: Sender<TransportResult<Response>>

The channel to send the response on.

Implementations

Source

impl InFlight

pub fn new( request: SerializedRequest, channel_size: usize, ) -> (Self, Receiver<TransportResult<Response>>)

Create a new in-flight request.

pub fn is_subscription(&self) -> bool

Check if the request is a subscription.

pub const fn request(&self) -> &SerializedRequest

Get a reference to the serialized request.

This is used to (re-)send the request over the transport.

pub fn fulfill(self, resp: Response) -> Option<(SubId, Self)>

Fulfill the request with a response. This consumes the in-flight request. If the request is a subscription and the response is not an error, the subscription ID and the in-flight request are returned.